@@ -55,7 +55,9 @@ cohort |>
 #    numberExposures = TRUE,
 #    numberEras = TRUE,
 #    daysExposed = TRUE,
+#    daysPrescribed = TRUE,
 #    timeToExposure = TRUE,
+#    initialExposureDuration = TRUE,
 #    initialQuantity = TRUE,
 #    cumulativeQuantity = TRUE,
 #    initialDailyDose = TRUE,
@@ -79,7 +81,9 @@ cdm$drug_utilisation_example <- cdm$cohort1 |>
     numberExposures = FALSE,
     numberEras = FALSE,
     daysExposed = FALSE,
+    daysPrescribed = FALSE,
     timeToExposure = FALSE,
+    initialExposureDuration = FALSE,
     initialQuantity = TRUE,
     cumulativeQuantity = TRUE,
     initialDailyDose = TRUE,
@@ -108,6 +112,7 @@ duResults <- summariseDrugUtilisation(
   numberExposures = TRUE,
   numberEras = TRUE,
   daysExposed = TRUE,
+  daysPrescribed = TRUE,
   timeToExposure = TRUE,
   initialExposureDuration = TRUE,
   initialQuantity = TRUE,
@@ -142,7 +147,9 @@ duResults <- cdm$cohort1 |>
     numberExposures = TRUE,
     numberEras = TRUE,
     daysExposed = TRUE,
+    daysPrescribed = TRUE,
     timeToExposure = TRUE,
+    initialExposureDuration = TRUE,
     initialQuantity = TRUE,
     cumulativeQuantity = TRUE,
     initialDailyDose = TRUE,
